==> emodpy_tbhiv-0.0.6-py3-none-any.whl: emodpy_tbhiv/interventions/sub_clinical_test.py <==
from emod_api import schema_to_class as s2c
import json

#dupe_policy = "Replace" # or "Add" or "Abort" -- from covid branch

def DiagnosticSubClinical(
        camp,
        trigger_treatment_list,
        base_sensitivity_active_no_HIV = 0,
        base_specificity = 0.95,
        cd4_strata=[100.0, 200.0, 1000.0], 
        strata_sensitivity = [0.56, 0.49, 0.15 ], 
        subclinical_only= 1.0, 
        pos_event='LAM_Positive', 
        neg_event='LAM_Negative', 
        def_event='LAM_Default',
        treatment_fraction= 1,
        start_day=0,
        duration=-1,
        property_restrictions_list=[],
        nodeIDs=[],
        black_period=0,
        black_trigger='Blackout',
        event_name='TB Diagnosis Active Simple'):
    """
    DiagnosticSubClinical
    :param TBD
    Note start_day is initialized as 1, recommend that this be aligned with the start of the simulation
    """
    schema_path = camp.schema_path
    # First, get the objects
    event = s2c.get_class_with_defaults( "CampaignEvent", schema_path )
    coordinator = s2c.get_class_with_defaults( "StandardEventCoordinator", schema_path )
    if coordinator is None:
        print( "s2c.get_class_with_defaults returned None. Maybe no schema.json was provided." )
        return "" 

    intervention = s2c.get_class_with_defaults( "DiagnosticSubClinical", schema_path )

    meta_intervention = s2c.get_class_with_defaults( "NodeLevelHealthTriggeredIV", schema_path )
    #meta_intervention.Demographic_Coverage=coverage
    meta_intervention.Duration=duration
    meta_intervention.Trigger_Condition_List.extend(trigger_treatment_list)
    meta_intervention.Blackout_Period = black_period
    meta_intervention.Blackout_Event_Trigger = black_trigger
    meta_intervention.Property_Restrictions.extend(property_restrictions_list)
    meta_intervention.Actual_IndividualIntervention_Config = intervention
    meta_intervention.pop( "Actual_NodeIntervention_Config" )
    meta_intervention.pop("Node_Property_Restrictions")
    meta_intervention.pop("Property_Restrictions_Within_Node")

    # Second, hook them up
    event.Event_Coordinator_Config = coordinator
    coordinator.Intervention_Config = meta_intervention
    event.Start_Day = float(start_day)

    # Third, do the actual settings
    intervention.Treatment_Fraction = treatment_fraction
    intervention.Base_Sensitivity = base_sensitivity_active_no_HIV
    intervention.Base_Specificity = base_specificity
    intervention.Test_CD4_Strata = cd4_strata
    intervention.Strata_Sensitivity = strata_sensitivity

    #intervention.Days_To_Diagnosis = 0
    intervention.Event_Or_Config = 'Event'
    intervention.SubClinical_Only = subclinical_only
    intervention.Positive_Diagnosis_Event = camp.get_event( pos_event )
    intervention.Negative_Diagnosis_Event = camp.get_event( neg_event )
    intervention.Defaulters_Event = camp.get_event( def_event )
    #intervention.Duplicate_Policy = dupe_policy

    # Fourth/finally, purge the schema bits
    coordinator.finalize()
    intervention.finalize()
    meta_intervention.finalize()
    event.finalize()
    event["Name"] = event_name
    event["Listening"] = list()
    event["Listening"].extend( trigger_treatment_list )
    event["Listening"].append( black_trigger )
    event["Broadcasting"] = [ pos_event, neg_event, def_event ]

    return event

def new_intervention_as_file( start_day, filename=None ):
    campaign = {}
    campaign["Events"] = []
    campaign["Events"].append( new_intervention( start_day, vaccine_type, iv_name ) )
    if filename is None:
        filename = "subclinical.json"
    with open( filename, "w" ) as camp_file:
        json.dump( campaign, camp_file, sort_keys=True, indent=4 )
    return filename

==> emodpy_tbhiv-0.1.8.dev0-py3-none-any.whl: emodpy_tbhiv/interventions/sub_clinical_test.py <==
from emod_api import schema_to_class as s2c
import json

#dupe_policy = "Replace" # or "Add" or "Abort" -- from covid branch

def DiagnosticSubClinical(
        camp,
        trigger_treatment_list,
        base_sensitivity_active_no_HIV = 0,
        base_specificity = 0.95,
        cd4_strata=[100.0, 200.0, 1000.0], 
        strata_sensitivity = [0.56, 0.49, 0.15 ], 
        subclinical_only= 1.0, 
        pos_event='LAM_Positive', 
        neg_event='LAM_Negative', 
        def_event='LAM_Default',
        treatment_fraction= 1,
        start_day=0,
        duration=-1,
        property_restrictions_list=[],
        nodeIDs=[],
        black_period=0,
        black_trigger='Blackout',
        event_name='TB Diagnosis Active Simple'):
    """
    DiagnosticSubClinical
    :param TBD
    Note start_day is initialized as 1, recommend that this be aligned with the start of the simulation
    """
    schema_path = camp.schema_path
    # First, get the objects
    event = s2c.get_class_with_defaults( "CampaignEvent", schema_path )
    coordinator = s2c.get_class_with_defaults( "StandardEventCoordinator", schema_path )
    if coordinator is None:
        print( "s2c.get_class_with_defaults returned None. Maybe no schema.json was provided." )
        return "" 

    intervention = s2c.get_class_with_defaults( "DiagnosticSubClinical", schema_path )

    meta_intervention = s2c.get_class_with_defaults( "NodeLevelHealthTriggeredIV", schema_path )
    #meta_intervention.Demographic_Coverage=coverage
    meta_intervention.Duration=duration
    meta_intervention.Trigger_Condition_List.extend([camp.get_event(e) for e in trigger_treatment_list])
    meta_intervention.Blackout_Period = black_period
    meta_intervention.Blackout_Event_Trigger = black_trigger
    meta_intervention.Property_Restrictions.extend(property_restrictions_list)
    meta_intervention.Actual_IndividualIntervention_Config = intervention
    meta_intervention.pop( "Actual_NodeIntervention_Config" )
    meta_intervention.pop("Node_Property_Restrictions")
    meta_intervention.pop("Property_Restrictions_Within_Node")

    # Second, hook them up
    event.Event_Coordinator_Config = coordinator
    coordinator.Intervention_Config = meta_intervention
    event.Start_Day = float(start_day)

    # Third, do the actual settings
    intervention.Treatment_Fraction = treatment_fraction
    intervention.Base_Sensitivity = base_sensitivity_active_no_HIV
    intervention.Base_Specificity = base_specificity
    intervention.Test_CD4_Strata = cd4_strata
    intervention.Strata_Sensitivity = strata_sensitivity

    #intervention.Days_To_Diagnosis = 0
    intervention.Event_Or_Config = 'Event'
    intervention.SubClinical_Only = subclinical_only
    intervention.Positive_Diagnosis_Event = camp.get_event( pos_event )
    intervention.Negative_Diagnosis_Event = camp.get_event( neg_event )
    intervention.Defaulters_Event = camp.get_event( def_event )
    #intervention.Duplicate_Policy = dupe_policy

    # Fourth/finally, purge the schema bits
    coordinator.finalize()
    intervention.finalize()
    meta_intervention.finalize()
    event.finalize()
    event["Name"] = event_name
    event["Listening"] = list()
    event["Listening"].extend( trigger_treatment_list )
    event["Listening"].append( black_trigger )
    event["Broadcasting"] = [ pos_event, neg_event, def_event ]

    return event

def new_intervention_as_file( start_day, filename=None ):
    campaign = {}
    campaign["Events"] = []
    campaign["Events"].append( new_intervention( start_day, vaccine_type, iv_name ) )
    if filename is None:
        filename = "subclinical.json"
    with open( filename, "w" ) as camp_file:
        json.dump( campaign, camp_file, sort_keys=True, indent=4 )
    return filename
